@@ -1,17 +1,14 @@
-#  Licensed to the Apache Software Foundation (ASF) under one or more
-#  contributor license agreements. See the NOTICE file distributed with
-#  this work for additional information regarding copyright ownership.
-#  The ASF licenses this file to You under the Apache License, Version 2.0
-#  (the "License"); you may not use this file except in compliance with
-#  the License. You may obtain a copy of the License at
-#
+#  Copyright 2021 Collate
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 #  http://www.apache.org/licenses/LICENSE-2.0
-#
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+
 import logging
 import os
 import pathlib
@@ -19,12 +16,15 @@ import subprocess
 import sys
 import time
 import traceback
+import tempfile
+import pathlib
 from datetime import timedelta
 
 import click
 import requests as requests
 from pydantic import ValidationError
 
+from metadata.__version__ import get_metadata_version
 from metadata.config.common import load_config_file
 from metadata.ingestion.api.workflow import Workflow
 
@@ -33,8 +33,6 @@ logger = logging.getLogger(__name__)
 logging.getLogger("urllib3").setLevel(logging.WARN)
 min_memory_limit = 3 * 1024 * 1024 * 1000
 calc_gb = 1024 * 1024 * 1000
-local_metadata = "com.docker.compose.project=local-metadata"
-release = "com.docker.compose.project=tmp"
 # Configure logger.
 BASE_LOGGING_FORMAT = (
     "[%(asctime)s] %(levelname)-8s {%(name)s:%(lineno)d} - %(message)s"
@@ -48,6 +46,7 @@ def check() -> None:
 
 
 @click.group()
+@click.version_option(get_metadata_version())
 @click.option("--debug/--no-debug", default=False)
 def metadata(debug: bool) -> None:
     if os.getenv("METADATA_DEBUG", False):
@@ -72,7 +71,7 @@ def ingest(config: str) -> None:
     workflow_config = load_config_file(config_file)
 
     try:
-        logger.info(f"Using config: {workflow_config}")
+        logger.debug(f"Using config: {workflow_config}")
         workflow = Workflow.create(workflow_config)
     except ValidationError as e:
         click.echo(e, err=True)
@@ -130,19 +129,6 @@ def report(config: str) -> None:
         ) from exc
 
 
-def get_list(docker_type, all_check: bool = None):
-    filter_kwargs = {
-        "filters": {"label": local_metadata},
-    }
-    if all_check:
-        filter_kwargs["all"] = all_check
-    stop_containers = docker_type.list(**filter_kwargs)
-    if len(stop_containers) == 0:
-        filter_kwargs["filters"] = {"label": release}
-        return docker_type.list(**filter_kwargs)
-    return stop_containers
-
-
 @metadata.command()
 @click.option("--start", help="Start release Docker containers", is_flag=True)
 @click.option("--stop", help="Stop Docker containers (local and release)", is_flag=True)
@@ -168,18 +154,18 @@ def get_list(docker_type, all_check: bool = None):
 def docker(start, stop, clean, type, path) -> None:
     """
     Checks Docker Memory Allocation
-    Run Latest Release Docker - metadata docker --run
-    Run Local Docker - metadata docker --run -t local -p path/to/docker-compose.yml
+    Run Latest Release Docker - metadata docker --start
+    Run Local Docker - metadata docker --start -t local -p path/to/docker-compose.yml
     """
+
     try:
         import docker as sys_docker
-
-        from metadata.ingestion.ometa.client import APIError
         from metadata.ingestion.ometa.ometa_api import OpenMetadata
         from metadata.ingestion.ometa.openmetadata_rest import MetadataServerConfig
 
         client = sys_docker.from_env()
         docker_info = client.info()
+
         if docker_info["MemTotal"] < min_memory_limit:
             raise MemoryError
         if start:
@@ -191,7 +177,7 @@ def docker(start, stop, clean, type, path) -> None:
                     )
                 start_time = time.time()
                 subprocess.run(
-                    f"docker compose -f {path} up --build -d",
+                    f"docker-compose -f {path} up --build -d",
                     shell=True,
                 )
                 elapsed = time.time() - start_time
@@ -200,18 +186,30 @@ def docker(start, stop, clean, type, path) -> None:
                 )
             else:
                 logger.info("Running Latest Release Docker")
+
                 r = requests.get(
                     "https://raw.githubusercontent.com/open-metadata/OpenMetadata/main/docker/metadata/docker-compose.yml"
                 )
-                open("/tmp/docker-compose.yml", "wb").write(r.content)
+
+                docker_compose_file_path = (
+                    pathlib.Path(tempfile.gettempdir()) / "docker-compose.yml"
+                )
+                with open(docker_compose_file_path, "wb") as docker_compose_file_handle:
+                    docker_compose_file_handle.write(r.content)
+
                 start_time = time.time()
+
+                logger.info(f"docker-compose -f {docker_compose_file_path} up -d")
                 subprocess.run(
-                    f"docker compose -f /tmp/docker-compose.yml up -d", shell=True
+                    f"docker-compose -f {docker_compose_file_path} up -d", shell=True
                 )
                 elapsed = time.time() - start_time
                 logger.info(
                     f"Time took to get containers running: {str(timedelta(seconds=elapsed))}"
                 )
+
+                docker_compose_file_path.unlink(missing_ok=True)
+
             metadata_config = MetadataServerConfig.parse_obj(
                 {
                     "api_endpoint": "http://localhost:8585/api",
@@ -222,10 +220,10 @@ def docker(start, stop, clean, type, path) -> None:
             ometa_client = OpenMetadata(metadata_config).client
             while True:
                 try:
-                    ometa_client.get(f"/tables/name/bigquery.shopify.dim_customer")
+                    ometa_client.get(f"/tables/name/bigquery_gcp.shopify.dim_customer")
                     break
                 except Exception as err:
-                    sys.stdout.write('.')
+                    sys.stdout.write(".")
                     sys.stdout.flush()
                     time.sleep(5)
             elapsed = time.time() - start_time
@@ -240,26 +238,27 @@ def docker(start, stop, clean, type, path) -> None:
                 """\nHead to http://localhost:8585 to play around with OpenMetadata UI.
                 \nTo checkout Ingestion via Airflow, go to http://localhost:8080 \n(username: admin, password: admin)
                 """,
-                fg="bright_white",
+                fg="bright_blue",
             )
             click.secho(
                 "Need support? Get in touch on Slack: https://slack.open-metadata.org/",
                 fg="bright_magenta",
             )
         elif stop:
-            for container in get_list(client.containers):
-                logger.info(f"Stopping {container.name}")
-                container.stop()
+            for container in client.containers.list():
+                if "openmetadata_" in container.name:
+                    logger.info(f"Stopping {container.name}")
+                    container.stop()
         elif clean:
             logger.info("Removing Containers")
-            for container in get_list(client.containers, True):
-                container.remove(v=True, force=True)
-            logger.info("Removing Volumes")
-            for volume in get_list(client.volumes):
-                volume.remove(force=True)
+
+            for container in client.containers.list({all: True}):
+                if "openmetadata_" in container.name:
+                    container.remove(v=True, force=True)
             logger.info("Removing Networks")
-            for network in get_list(client.networks):
-                network.remove()
+            for network in client.networks.list():
+                if "app_net" in network.name:
+                    network.remove()
     except (ImportError, ModuleNotFoundError):
         click.secho(
             "Docker package not found, can you try `pip install 'openmetadata-ingestion[docker]'`",
@@ -271,7 +270,6 @@ def docker(start, stop, clean, type, path) -> None:
             f"{round(float(docker_info['MemTotal']) / calc_gb, 2)}",
             fg="red",
         )
-
     except sys_docker.errors.DockerException as err:
         click.secho(f"Error: Docker service is not up and running. {err}", fg="red")
     except Exception as err:
